@@ -27,6 +27,7 @@ import salt.utils.verify
 import salt.utils.yaml
 from salt.utils.immutabletypes import freeze
 
+from saltfactories.exceptions import FactoryNotRunning
 from saltfactories.exceptions import FactoryNotStarted
 from saltfactories.exceptions import FactoryTimeout
 from saltfactories.utils import platform
@@ -434,6 +435,13 @@ class ProcessFactory(SubprocessFactoryBase):
         return stdout, stderr, json_out
 
 
+@attr.s(kw_only=True)
+class StartDaemonCallArguments:
+
+    args = attr.ib()
+    kwargs = attr.ib()
+
+
 @attr.s(kw_only=True)
 class DaemonFactoryImpl(SubprocessFactoryImpl):
     """
@@ -444,6 +452,7 @@ class DaemonFactoryImpl(SubprocessFactoryImpl):
     before_terminate_callbacks = attr.ib(repr=False, hash=False, default=attr.Factory(list))
     after_start_callbacks = attr.ib(repr=False, hash=False, default=attr.Factory(list))
     after_terminate_callbacks = attr.ib(repr=False, hash=False, default=attr.Factory(list))
+    _start_args_and_kwargs = attr.ib(init=False, repr=False, hash=False)
 
     def register_before_start_callback(self, callback, *args, **kwargs):
         self.before_start_callbacks.append((callback, args, kwargs))
@@ -473,6 +482,10 @@ class DaemonFactoryImpl(SubprocessFactoryImpl):
         if self.is_running():
             log.warning("%s is already running.", self)
             return True
+        self._start_args_and_kwargs = StartDaemonCallArguments(
+            args=extra_cli_arguments,
+            kwargs={"max_start_attempts": max_start_attempts, "start_timeout": start_timeout},
+        )
         process_running = False
         start_time = time.time()
         start_attempts = max_start_attempts or self.factory.max_start_attempts
@@ -558,6 +571,7 @@ class DaemonFactoryImpl(SubprocessFactoryImpl):
             stdout=result.stdout,
             stderr=result.stderr,
             exitcode=result.exitcode,
+            cmdline=run_arguments,
         )
 
     def terminate(self):
@@ -588,6 +602,9 @@ class DaemonFactoryImpl(SubprocessFactoryImpl):
                         exc_info=True,
                     )
 
+    def get_start_arguments(self):
+        return self._start_args_and_kwargs
+
 
 @attr.s(kw_only=True)
 class DaemonFactory(SubprocessFactoryBase):
@@ -651,6 +668,34 @@ class DaemonFactory(SubprocessFactoryBase):
         )
         return self
 
+    @contextlib.contextmanager
+    def stopped(self):
+        """
+        This context manager will stop the factory while the context is in place, it re-starts it once out of
+        context.
+
+        For example:
+
+        .. code-block:: python
+
+            assert factory.is_running() is True
+
+            with factory.stopped():
+                assert factory.is_running() is False
+
+            assert factory.is_running() is True
+        """
+        if not self.is_running():
+            raise FactoryNotRunning("{} is not running ".format(self))
+        start_arguments = self.impl.get_start_arguments()
+        try:
+            self.terminate()
+            yield
+        except Exception:  # pylint: disable=broad-except,try-except-raise
+            raise
+        else:
+            return self.started(*start_arguments.args, **start_arguments.kwargs)
+
     def run_start_checks(self, started_at, timeout_at):
         log.debug("%s is running start checks", self)
         check_ports = set(self.get_check_ports())
@@ -812,12 +857,13 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
     # Override the following to default to non-mandatory and to None
     display_name = attr.ib(init=False, default=None)
     _minion_tgt = attr.ib(repr=False, init=False, default=None)
+    merge_json_output = attr.ib(repr=False, default=True)
 
     __cli_timeout_supported__ = attr.ib(repr=False, init=False, default=False)
     __cli_log_level_supported__ = attr.ib(repr=False, init=False, default=True)
     __cli_output_supported__ = attr.ib(repr=False, init=False, default=True)
-    # Override the following to default to non-mandatory and to None
-    display_name = attr.ib(init=False, default=None)
+    __json_output__ = attr.ib(repr=False, init=False, default=False)
+    __merge_json_output__ = attr.ib(repr=False, init=False, default=True)
 
     def _get_impl_class(self):
         return SaltCliFactoryImpl
@@ -837,7 +883,9 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
     def get_minion_tgt(self, minion_tgt=None):
         return minion_tgt
 
-    def build_cmdline(self, *args, minion_tgt=None, **kwargs):  # pylint: disable=arguments-differ
+    def build_cmdline(
+        self, *args, minion_tgt=None, merge_json_output=None, **kwargs
+    ):  # pylint: disable=arguments-differ
         """
         Construct a list of arguments to use when starting the subprocess
 
@@ -848,6 +896,10 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
                 Keyword arguments will be converted into ``key=value`` pairs to be consumed by the salt CLI's
             minion_tgt(str):
                 The minion ID to target
+            merge_json_output(bool):
+                The default behavior of salt outputters is to print one line per minion return, which makes
+                parsing the whole output as JSON impossible when targeting multiple minions. If this value
+                is ``True``, an attempt is made to merge each JSON line into a single dictionary.
         """
         log.debug(
             "Building cmdline. Minion target: %s; Input args: %s; Input kwargs: %s;",
@@ -856,6 +908,10 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
             kwargs,
         )
         minion_tgt = self._minion_tgt = self.get_minion_tgt(minion_tgt=minion_tgt)
+        if merge_json_output is None:
+            self.__merge_json_output__ = self.merge_json_output
+        else:
+            self.__merge_json_output__ = merge_json_output
         cmdline = []
 
         args = list(args)
@@ -910,16 +966,31 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
 
         # Handle the output flag
         if self.__cli_output_supported__:
-            for arg in args:
+            json_output = False
+            for idx, arg in enumerate(args):
                 if not isinstance(arg, str):
                     continue
                 if arg in ("--out", "--output"):
+                    self.__json_output__ = args[idx + 1] == "json"
                     break
                 if arg.startswith(("--out=", "--output=")):
+                    self.__json_output__ = arg.split("=")[-1].strip() == "json"
                     break
             else:
                 # No output was passed, the default output is JSON
                 cmdline.append("--out=json")
+                self.__json_output__ = True
+            if self.__json_output__:
+                for arg in args:
+                    if not isinstance(arg, str):
+                        continue
+                    if arg in ("--out-indent", "--output-indent"):
+                        break
+                    if arg.startswith(("--out-indent=", "--output-indent=")):
+                        break
+                else:
+                    # Default to one line per output
+                    cmdline.append("--out-indent=0")
 
         if self.__cli_log_level_supported__:
             # Handle the logging flag
@@ -954,12 +1025,23 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
         return cmdline
 
     def process_output(self, stdout, stderr, cmdline=None):
-        stdout, stderr, json_out = super().process_output(stdout, stderr, cmdline=cmdline)
+        json_out = None
+        if stdout and self.__json_output__:
+            try:
+                json_out = json.loads(stdout)
+            except ValueError:
+                if self.__merge_json_output__:
+                    try:
+                        json_out = json.loads(stdout.replace("}\n{", ", "))
+                    except ValueError:
+                        pass
+            if json_out is None:
+                log.debug("%s failed to load JSON from the following output:\n%r", self, stdout)
         if (
             self.__cli_output_supported__
             and json_out
             and isinstance(json_out, str)
-            and "--out=json" in cmdline
+            and self.__json_output__
         ):
             # Sometimes the parsed JSON is just a string, for example:
             #  OUTPUT: '"The salt master could not be contacted. Is master running?"\n'
@@ -968,7 +1050,12 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
             # In this case, we assign the loaded JSON to stdout and reset json_out
             stdout = json_out
             json_out = None
-        if self.__cli_output_supported__ and json_out and self._minion_tgt:
+        if (
+            self.__cli_output_supported__
+            and json_out
+            and self._minion_tgt
+            and self._minion_tgt != "*"
+        ):
             try:
                 json_out = json_out[self._minion_tgt]
             except KeyError:
